aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichael Muré <batolettre@gmail.com>2019-11-03 14:06:29 +0100
committerMichael Muré <batolettre@gmail.com>2019-11-03 14:06:29 +0100
commit912b5ca320891f2a4f1a88f1a137ce8ee46a1a03 (patch)
treec7cf8f08ccb8b6ac5c7e8ed0268a7d4b9ab0a2a9
parentf72a9dc62ba20546b2cdeb466434fc1900741a4f (diff)
downloadgit-bug-912b5ca320891f2a4f1a88f1a137ce8ee46a1a03.tar.gz
drop support for go 1.9
-rw-r--r--.travis.yml4
-rw-r--r--Gopkg.lock6
-rw-r--r--git-bug.go4
-rw-r--r--vendor/github.com/theckman/goconstraint/go1.10/gte/constraint.go8
-rw-r--r--vendor/github.com/theckman/goconstraint/go1.10/gte/go110.go7
-rw-r--r--vendor/github.com/theckman/goconstraint/go1.9/gte/constraint.go8
-rw-r--r--vendor/github.com/theckman/goconstraint/go1.9/gte/go19.go7
7 files changed, 22 insertions, 22 deletions
diff --git a/.travis.yml b/.travis.yml
index 5a46a981..cac34dc7 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -1,13 +1,13 @@
matrix:
include:
- language: go
- go: "1.9"
- - language: go
go: "1.10"
- language: go
go: "1.11"
- language: go
go: "1.12"
+ - language: go
+ go: "1.13"
- language: node_js
node_js: 8
before_install:
diff --git a/Gopkg.lock b/Gopkg.lock
index bc8722cd..194e6c33 100644
--- a/Gopkg.lock
+++ b/Gopkg.lock
@@ -321,9 +321,9 @@
version = "v1.2.2"
[[projects]]
- digest = "1:823766f4e1833bd562339317d905475fe46789da3863b2da7a1871f9f12bb4b3"
+ digest = "1:8d784da270f610f505e2c9785faec4c81d4a6a6a1034412685a4bf2cffe24cef"
name = "github.com/theckman/goconstraint"
- packages = ["go1.9/gte"]
+ packages = ["go1.10/gte"]
pruneopts = "UT"
revision = "93babf24513d0e8277635da8169fcc5a46ae3f6a"
version = "v1.11.0"
@@ -490,7 +490,7 @@
"github.com/spf13/cobra/doc",
"github.com/stretchr/testify/assert",
"github.com/stretchr/testify/require",
- "github.com/theckman/goconstraint/go1.9/gte",
+ "github.com/theckman/goconstraint/go1.10/gte",
"github.com/vektah/gqlgen/client",
"github.com/vektah/gqlparser",
"github.com/vektah/gqlparser/ast",
diff --git a/vendor/github.com/theckman/goconstraint/go1.10/gte/constraint.go b/vendor/github.com/theckman/goconstraint/go1.10/gte/constraint.go
new file mode 100644
index 00000000..33dc1161
--- /dev/null
+++ b/vendor/github.com/theckman/goconstraint/go1.10/gte/constraint.go
@@ -0,0 +1,8 @@
+// The contents of this file has been released in to the Public Domain.
+
+// Package gtego110 should only be used as a blank import. If imported, it
+// will only compile if the Go runtime version is >= 1.10.
+package gtego110
+
+// This will fail to compile if the Go runtime version isn't >= 1.10.
+var _ = __SOFTWARE_REQUIRES_GO_VERSION_1_10__
diff --git a/vendor/github.com/theckman/goconstraint/go1.10/gte/go110.go b/vendor/github.com/theckman/goconstraint/go1.10/gte/go110.go
new file mode 100644
index 00000000..5d586ff9
--- /dev/null
+++ b/vendor/github.com/theckman/goconstraint/go1.10/gte/go110.go
@@ -0,0 +1,7 @@
+// The contents of this file has been released in to the Public Domain.
+
+// +build go1.10
+
+package gtego110
+
+const __SOFTWARE_REQUIRES_GO_VERSION_1_10__ = uint8(0)
diff --git a/vendor/github.com/theckman/goconstraint/go1.9/gte/constraint.go b/vendor/github.com/theckman/goconstraint/go1.9/gte/constraint.go
deleted file mode 100644
index ed67fefc..00000000
--- a/vendor/github.com/theckman/goconstraint/go1.9/gte/constraint.go
+++ /dev/null
@@ -1,8 +0,0 @@
-// The contents of this file has been released in to the Public Domain.
-
-// Package gtego19 should only be used as a blank import. If imported, it
-// will only compile if the Go runtime version is >= 1.9.
-package gtego19
-
-// This will fail to compile if the Go runtime version isn't >= 1.9.
-var _ = __SOFTWARE_REQUIRES_GO_VERSION_1_9__
diff --git a/vendor/github.com/theckman/goconstraint/go1.9/gte/go19.go b/vendor/github.com/theckman/goconstraint/go1.9/gte/go19.go
deleted file mode 100644
index 446a5ee3..00000000
--- a/vendor/github.com/theckman/goconstraint/go1.9/gte/go19.go
+++ /dev/null
@@ -1,7 +0,0 @@
-// The contents of this file has been released in to the Public Domain.
-
-// +build go1.9
-
-package gtego19
-
-const __SOFTWARE_REQUIRES_GO_VERSION_1_9__ = uint8(0)
diff --git a/git-bug.go b/git-bug.go
index cf59182f..50415ae2 100644
--- a/git-bug.go
+++ b/git-bug.go
@@ -9,8 +9,8 @@ package main
import (
"github.com/MichaelMure/git-bug/commands"
- // minimal go version is 1.9
- _ "github.com/theckman/goconstraint/go1.9/gte"
+ // minimal go version is 1.10
+ _ "github.com/theckman/goconstraint/go1.10/gte"
)
func main() {